@@ -39,7 +39,7 @@ import json
 import datetime
 
 __name__ = 'BenBotAsync'
-__version__ = '2.1.2'
+__version__ = '2.2.1'
 __author__ = 'xMistt'
 
 BEN_BOT_BASE = 'https://benbotfn.tk/api/v1'
@@ -173,7 +173,7 @@ async def get_cosmetic(**params: Any) -> BRCosmetic:
             return BRCosmetic(data)
 
 
-async def get_cosmetic(**params: Any) -> list:
+async def get_cosmetics(**params: Any) -> list:
     """|coro|
 
     Fetches first cosmetic matching parameters. All parameters are optional but at least 1 is required.
